@@ -153,82 +153,6 @@ stats_quotes <- function(x, data2, digits = 2) {
   res
 }
 
-#' Cross-tabulation.
-#'
-#' \code{cross_tab} is a wrapper to functions from package \code{moonBook} to construct tables of descriptive statistics stratified by levels of a categorical outcome.
-#'
-#' @param object When chaining, this holds an object produced in the earlier portions of the chain. Most users can safely ignore this argument. See details and examples.
-#' @param formula A formula with shape: \code{y ~ x}, where \code{y} is a categorical outcome and \code{x} is the explanatory variable or a set of explanatory variables (see Details and Examples).
-#' @param data A data frame where the variables in the \code{formula} can be found.
-#' @param label A character, label to be used for the outcome (for non-labelled data).
-#' @param show.total Logical, show column with totals?
-#' @param p_val Logical, show p-values?
-#' @param pad Numerical, padding above and bellow rows.
-#' @param width Numerical, proportional width of the table.
-#' @param method An integer indicating methods for continuous variables.
-#' 1 Reports means and standard deviations.
-#' 2 Reports medians and interquartile ranges.
-#' @param ... Additional arguments passed to \code{\link[moonBook]{mytable_sub}}.
-#' @details Function \code{cross_tab} is a relatively simple wrapper to function \code{mytable} of package \code{moonBook}. Its main purpose is to construct contingency tables but it can also be used to report a table with descriptives for all variables as long as they are still stratified by the outcome. Please see examples to see how to list explanatory variables. For categorical explanatory variables, the function reports column percentages. If data is labelled with \code{sjlabelled}, the label of the outcome (dependent) variable is used to name the outcome; this name can be changed with argument \code{label}.
-#' @return A huxtable with descriptive statistics stratified by levels of the outcome.
-#' @seealso \code{\link[moonBook]{mytable}}
-cross_tab <- function(object = NULL, formula = NULL, data = NULL, label = NULL,
-                      show.total = TRUE, p_val = FALSE, pad = 3, width = 0.8, method = 1, ...) {
-  .Deprecated("cross_tbl")
-  if (inherits(object, "formula")) {
-    formula <- object
-    object <- NULL
-  }
-  if (inherits(object, "data.frame")) {
-    data <- object
-    object <- NULL
-  }
-  vars <- all.vars(formula)
-  dependent <- vars[1]
-  explanatory <- vars[-1]
-  nv <- length(explanatory)
-  outcome <- data[[dependent]]
-  k <- length(levels(outcome))
-  nl <- k + 2
-  nm <- k + 1
-  nl2 <- nl + 1
-  if (is.null(sjlabelled::get_label(outcome)) == FALSE & is.null(label)) {
-    lab <- sjlabelled::get_label(outcome)
-  } else {
-    lab <- ifelse(is.null(label), dependent, label)
-  }
-  tbl <- moonBook::mytable(formula,
-    data = data, show.total = show.total,
-    method = method, ...
-  ) %>% moonBook::mytable2df()
-  if (p_val == TRUE) {
-    tvl <- tbl
-  } else {
-    tvl <- tbl %>% dplyr::select(-ncol(tbl))
-  }
-  names(tvl)[1] <- " "
-
-  res <- tvl %>%
-    huxtable::as_hux() %>%
-    huxtable::set_align(huxtable::everywhere, 2:nl, "right") %>%
-    huxtable::insert_row(c(" ", lab), fill = " ") %>%
-    huxtable::merge_cells(1, 2:nm) %>%
-    huxtable::set_header_rows(1, TRUE) %>%
-    huxtable::set_align(1:3, huxtable::everywhere, "center")
-  if (nv > 1) {
-    res <- res
-  } else {
-    res <- res %>% huxtable::set_bold(4, 1)
-  }
-
-  res <- res %>%
-    huxtable::set_top_padding(pad) %>%
-    huxtable::set_bottom_padding(pad) %>%
-    huxtable::set_width(width)
-
-  res
-}
-
 #' Table of descriptive statistics by categorical variable.
 #'
 #' \code{cross_tbl} is a wrapper to function  from package \code{\link[gtsummary]{tbl_summary}} that constructs tables of descriptive statistics stratified by levels of a categorical outcome.
